//
// BaseComponentLib.cpp
// A shared lib for base components
//

#include "PaletteEntry.h"
#include <List.h>

// Specialized types for this library
#include "ButtonEntry.h"
#include "BoxEntry.h"
#include "CheckBoxEntry.h"
#include "RadioButtonEntry.h"
#include "SliderEntry.h"
#include "ListViewEntry.h"
#include "OutlineListViewEntry.h"
#include "ColorControlEntry.h"
#include "StringViewEntry.h"
#include "TextViewEntry.h"
#include "TextControlEntry.h"

//
// Global objects
//
BList _componentList;

//
// EXPORTS
//

// Return the number of components defined in this library.
uint32 CountComponents(image_id imgID)
{
	return _componentList.CountItems();
}

// Return a pointer to the palette item specified at index
TPaletteEntry *EntryAt(uint32 index)
{
  if((index >= 0) && (index < (uint32)_componentList.CountItems()))
  {
  	return (TPaletteEntry *)(_componentList.ItemAt(index));
  }
  return 0;
}

// Time to initialize
bool InitComponentLib(image_id imgID)
{
  bool result = true;
  
  // Create the palette entries that go in this library,
  // and add them to _componentList.
  _componentList.AddItem(new TButtonEntry(imgID));
  _componentList.AddItem(new TCheckBoxEntry(imgID));
  _componentList.AddItem(new TBoxEntry(imgID));
  _componentList.AddItem(new TRadioButtonEntry(imgID));
  _componentList.AddItem(new TSliderEntry(imgID));
  _componentList.AddItem(new TListViewEntry(imgID));
  _componentList.AddItem(new TOutlineListViewEntry(imgID));
  _componentList.AddItem(new TColorControlEntry(imgID));
  _componentList.AddItem(new TStringViewEntry(imgID));
  _componentList.AddItem(new TTextControlEntry(imgID));
  return result;
}

// Clean-up time
bool UnInitComponentLib(image_id imgID)
{
  bool result = true;
  
  TPaletteEntry *entry;
  for(int i = 0; (entry = (TPaletteEntry *)_componentList.ItemAt(i)); i++)
  {
  	delete entry;
  }
    
  _componentList.MakeEmpty();
  return result; 
}

// eof
