//
// CheckBoxEntry.cpp
// Implementation for TCheckBoxEntry class
//

#include <stdio.h>
#include <string>
#include "CheckBoxEntry.h"

enum {
	PMI_ABOUT = 'ham!'
};

//
// TCheckBoxEntry implementation
//
TComponent *TCheckBoxEntry::CreateComponent(BView *view, TFormDesigner *designer, BRect rect)
{
	TDesignCheckBox *btn = new TDesignCheckBox(rect, "CheckBox", "CheckBox", designer);
	btn->SetClassName(ClassName());
	
	view->LockLooper();
	view->AddChild(btn);
	view->UnlockLooper();
	return btn;
}

//
// TDesignCheckBox implementation
//
TDesignCheckBox::TDesignCheckBox(BRect frame, const char *name, const char *caption, TFormDesigner *designer)
:	BCheckBox(frame, name, caption, 0)
, TControlComponent(0, designer, ctVisual)
{
	SetComponentName(name);
	SetDTView(this); // ALWAYS do this
	InitPropertyList(); // and this
	InitPropertyValues();
	InitEventList();
	InitEventValues();
}

void TDesignCheckBox::MouseDown(BPoint pt)
{
	DesignerMouseDown(pt, Bounds(), this);
	Invalidate();
}

void TDesignCheckBox::Draw(BRect updateRect)
{
	BCheckBox::Draw(updateRect);
	DesignerDrawSelection();
}

const char *TDesignCheckBox::GetPropertyValue(const char *propName) const
{
	string s = propName;
	
	if(s == "Checked")
	{
		return Value() == B_CONTROL_ON ? "true" : "false";
	}
	
	return TControlComponent::GetPropertyValue(propName);
}

void TDesignCheckBox::SetPropertyValue(const char *propName, const char *value)
{
	printf("TDesignCheckBox::SetPropertyValue('%s', '%s')\n", propName, value);
	if((!propName) || (!value)) return;
	
	string s = propName;
	string v = value;
	
	if(s == "Checked")
	{
		if(LockLooper())
		{
			SetValue(v == "true"? B_CONTROL_ON : B_CONTROL_OFF);
			UnlockLooper();
		}
		StoreProperty(propName, value);
		return;
	}
	
	TControlComponent::SetPropertyValue(propName, value);
}

void TDesignCheckBox::InitPropertyList(void)
{
	TControlComponent::InitPropertyList();
	
	AddPropAndEditor(
		new TProperty(this, "Checked", "false")
	, new TBoolProperty(this, 0)
	);
}

void TDesignCheckBox::InitEventList(void)
{
	TControlComponent::InitEventList();
	
	AddEvent(new TEvent("OnChecked", "bool checked"));
}

void TDesignCheckBox::InitPropertyValues(void)
{
	TControlComponent::InitPropertyValues();
}

void TDesignCheckBox::InitEventValues(void)
{
	TControlComponent::InitEventValues();
}

void TDesignCheckBox::OnSetConstructorParams(BString &s)
{
	TControlComponent::OnSetConstructorParams(s);	
	
	char buf[256] = "";
	sprintf(
		buf
	, "\"%s\", 0"
	, GetPropertyValue("Label")
	);
	s += buf;
}

// eof
