//
// TextViewEntry.cpp
// Implementation for TTextViewEntry class
//

#include <stdio.h>
#include <string>
#include "TextViewEntry.h"

enum {
	PMI_ABOUT = 'ham!'
};

//
// property editors for TextView controls
//
class TSVAlignmentProperty: public TPickListProperty {
public:
	TSVAlignmentProperty(TComponent *Component, TProperty *prop)
	: TPickListProperty(Component, prop)
	{}
	
	virtual void GetValuePickList(TStringList *list)
	{
		list->MakeEmpty();
		list->AddItem("B_ALIGN_LEFT");
		list->AddItem("B_ALIGN_RIGHT");
		list->AddItem("B_ALIGN_CENTER");
	}
};


//
// TTextViewEntry implementation
//
TComponent *TTextViewEntry::CreateComponent(BView *view, TFormDesigner *designer, BRect rect)
{
	TDesignTextView *TextView = new TDesignTextView(rect, "TextView", "TextView", designer);
	TextView->SetClassName(ClassName());
	
	view->LockLooper();
	view->AddChild(TextView);
	view->UnlockLooper();
	return TextView;
}

//
// TDesignTextView implementation
//
TDesignTextView::TDesignTextView(BRect frame, const char *name, const char *caption, TFormDesigner *designer)
:	BTextView(frame, name, BRect(frame.left+2, frame.top+2, frame.right-2, frame.bottom-2), B_FOLLOW_LEFT | B_FOLLOW_TOP, B_WILL_DRAW)
, TControlComponent(0, designer, ctVisual)
{
	SetComponentName(name);
	SetDTView(this); // ALWAYS do this
	InitPropertyList(); // and this
	InitPropertyValues();
	InitEventList();
	InitEventValues();
}

void TDesignTextView::MouseDown(BPoint pt)
{
	BTextView::MouseDown(pt);
	DesignerMouseDown(pt, Bounds(), this);
	Invalidate();
}

void TDesignTextView::Draw(BRect updateRect)
{
	BTextView::Draw(updateRect);
	DesignerDrawSelection();
}

bool TDesignTextView::AddComponentContextMenuItems(BPopUpMenu *menu)
{
	return true;
}

bool TDesignTextView::HandleComponentContextMessage(BMessage *message)
{
	switch(message->what)
	{
		default: 
			return false;
	}
}

bool TDesignTextView::DefaultEditAction(BPoint pt)
{
	return false;
}

const char *TDesignTextView::GetPropertyValue(const char *propName) const
{
	string s = propName;
	
	if(s == "Text")
	{
		return Text();
	}
	
	return TControlComponent::GetPropertyValue(propName);
}

void TDesignTextView::SetPropertyValue(const char *propName, const char *value)
{
	printf("TDesignTextView::SetPropertyValue('%s', '%s')\n", propName, value);
	if((!propName) || (!value)) return;
	
	string s = propName;
	string v = value;
	
	if(s == "Text")
	{
		if(DTView()->LockLooper())
		{
			SetText(value);
			DTView()->UnlockLooper();
		}
		StoreProperty(propName, value);
		return;
	}
	
	if(s == "Alignment")
	{
		if(DTView()->LockLooper())
		{
			if(v == "B_ALIGN_RIGHT")
			{
				SetAlignment(B_ALIGN_RIGHT);
			}
			else if(v == "B_ALIGN_CENTER")
			{
				SetAlignment(B_ALIGN_CENTER);
			}
			else
			{
				SetAlignment(B_ALIGN_LEFT);
			}
			DTView()->UnlockLooper();
		}
		StoreProperty(propName, value);
		return;
	}
	
	TControlComponent::SetPropertyValue(propName, value);
}

void TDesignTextView::InitPropertyList(void)
{
	TControlComponent::InitPropertyList();
	
	AddPropAndEditor(
		new TProperty(this, "Text", "TextView")
	, new TStringProperty(this, 0)
	);
	
	AddPropAndEditor(	
		new TProperty(this, "Alignment", "B_ALIGN_LEFT")
	, new TSVAlignmentProperty(this, 0)	
	);
	
	RemoveProperty(FindProperty("Enabled"));
	RemoveProperty(FindProperty("Label"));
	
	FindProperty("Text")->SetQuoted(true);
}

void TDesignTextView::InitEventList(void)
{
	TControlComponent::InitEventList();
}

void TDesignTextView::InitPropertyValues(void)
{
	TControlComponent::InitPropertyValues();
}

void TDesignTextView::InitEventValues(void)
{
	TControlComponent::InitEventValues();
}

void TDesignTextView::MessageReceived(BMessage *message)
{
	if(!HandleComponentDesignMessage(message))
	{
		BTextView::MessageReceived(message);
	}
}

void TDesignTextView::OnSetConstructorParams(BString &s)
{
	TControlComponent::OnSetConstructorParams(s);	
	
	char buf[256] = "";
	sprintf(buf, "\"%s\"", FindProperty("Text")->Value());
	s += buf;
}


// eof
