//
// PaletteEntry.h
//

#ifndef _PaletteEntry_H
#define _PaletteEntry_H

#include <Button.h>
#include <image.h>
#include "ComponentDesign.h"

enum {
  MSG_PALENTRY = 'PalE'
};

const int PAL_BTN_WIDTH = 100;
const int PAL_BTN_HEIGHT = 24;

//
// Represents a button on the tool palette
//
class _EXPORT TPaletteEntry {
public:
  TPaletteEntry(image_id imgID, const char *name, const char *classname);
  virtual ~TPaletteEntry(void);

  const char *ClassName(void) const { return m_ClassName; }

  virtual TComponent *Component(void) { return m_Component; }
  virtual TComponent *CreateComponent(BView *, TFormDesigner *, BRect) { return m_Component; }
  virtual const char *ComponentName(void) const { return m_Name; }
  virtual void Init(BView *, BPoint where);
  virtual void GetButtonSize(BPoint *where);
  virtual const char *Copyright(void) const {return "Your name here"; }
  virtual void About(void);

protected:
  image_id m_imgID;
  const char *m_Name;
  const char *m_ClassName;
  BButton *m_button;
  TComponent *m_Component;
};

typedef bool (*TpfnInitComponentLib)(image_id);
typedef bool (*TpfnUnInitComponentLib)(image_id);
typedef uint32 (*TpfnCountComponents)(void);
typedef TPaletteEntry *(*TpfnEntryAt)(int);

// Tells the component library to initialize itself
extern "C" _EXPORT bool InitComponentLib(image_id imgID);

// Tells the component library it's time to clean up
extern "C" _EXPORT bool UnInitComponentLib(image_id imgID);

// Returns the number of components defined in this library.
extern "C" _EXPORT uint32 CountComponents(image_id imgID);

// Returns a pointer to the palette item specified at index
extern "C" _EXPORT TPaletteEntry *EntryAt(uint32 index);

#endif // _PaletteEntry_H
